@@ -382,6 +382,48 @@
 #define __NR_pkey_free		382
 #define __NR_statx		383
 #define __NR_arch_prctl		384
+#define __NR_io_pgetevents	385
+#define __NR_rseq		386
+#define __NR_semget		393
+#define __NR_semctl		394
+#define __NR_shmget		395
+#define __NR_shmctl		396
+#define __NR_shmat		397
+#define __NR_shmdt		398
+#define __NR_msgget		399
+#define __NR_msgsnd		400
+#define __NR_msgrcv		401
+#define __NR_msgctl		402
+#define __NR_clock_gettime64	403
+#define __NR_clock_settime64	404
+#define __NR_clock_adjtime64	405
+#define __NR_clock_getres_time64 406
+#define __NR_clock_nanosleep_time64 407
+#define __NR_timer_gettime64	408
+#define __NR_timer_settime64	409
+#define __NR_timerfd_gettime64	410
+#define __NR_timerfd_settime64	411
+#define __NR_utimensat_time64	412
+#define __NR_pselect6_time64	413
+#define __NR_ppoll_time64	414
+#define __NR_io_pgetevents_time64 416
+#define __NR_recvmmsg_time64	417
+#define __NR_mq_timedsend_time64 418
+#define __NR_mq_timedreceive_time64 419
+#define __NR_semtimedop_time64	420
+#define __NR_rt_sigtimedwait_time64 421
+#define __NR_futex_time64	422
+#define __NR_sched_rr_get_interval_time64 423
+#define __NR_pidfd_send_signal	424
+#define __NR_io_uring_setup	425
+#define __NR_io_uring_enter	426
+#define __NR_io_uring_register	427
+#define __NR_open_tree		428
+#define __NR_move_mount		429
+#define __NR_fsopen		430
+#define __NR_fsconfig		431
+#define __NR_fsmount		432
+#define __NR_fspick		433
 
 #define SYS_restart_syscall      0
 #define SYS_exit		  1
@@ -765,3 +807,45 @@
 #define SYS_pkey_free		382
 #define SYS_statx		383
 #define SYS_arch_prctl		384
+#define SYS_io_pgetevents	385
+#define SYS_rseq		386
+#define SYS_semget		393
+#define SYS_semctl		394
+#define SYS_shmget		395
+#define SYS_shmctl		396
+#define SYS_shmat		397
+#define SYS_shmdt		398
+#define SYS_msgget		399
+#define SYS_msgsnd		400
+#define SYS_msgrcv		401
+#define SYS_msgctl		402
+#define SYS_clock_gettime64	403
+#define SYS_clock_settime64	404
+#define SYS_clock_adjtime64	405
+#define SYS_clock_getres_time64 406
+#define SYS_clock_nanosleep_time64 407
+#define SYS_timer_gettime64	408
+#define SYS_timer_settime64	409
+#define SYS_timerfd_gettime64	410
+#define SYS_timerfd_settime64	411
+#define SYS_utimensat_time64	412
+#define SYS_pselect6_time64	413
+#define SYS_ppoll_time64	414
+#define SYS_io_pgetevents_time64 416
+#define SYS_recvmmsg_time64	417
+#define SYS_mq_timedsend_time64 418
+#define SYS_mq_timedreceive_time64 419
+#define SYS_semtimedop_time64	420
+#define SYS_rt_sigtimedwait_time64 421
+#define SYS_futex_time64	422
+#define SYS_sched_rr_get_interval_time64 423
+#define SYS_pidfd_send_signal	424
+#define SYS_io_uring_setup	425
+#define SYS_io_uring_enter	426
+#define SYS_io_uring_register	427
+#define SYS_open_tree		428
+#define SYS_move_mount		429
+#define SYS_fsopen		430
+#define SYS_fsconfig		431
+#define SYS_fsmount		432
+#define SYS_fspick		433
